VariableAttributes

Struct VariableAttributes 

pub struct VariableAttributes(/* private fields */);
Wrapper for UA_VariableAttributes from open62541_sys.

This owns the wrapped data. When the wrapper is dropped, the inner value is cleaned up with UA_clear() to release dynamically allocated memory held by the value.

Implementations

Source

impl VariableAttributes

pub fn with_data_type(self, data_type: &NodeId) -> Self

pub const fn with_value_rank(self, rank: i32) -> Self

pub fn with_array_dimensions(self, array_dimensions: &[u32]) -> Self

pub const fn with_access_level(self, access_level: &AccessLevelType) -> Self