pub struct Variant(/* private fields */);Expand description
Wrapper for
UA_Variant
from open62541_sys.
This owns the wrapped data. When the wrapper is dropped, the inner value is cleaned up
with UA_clear() to release dynamically allocated memory held by the value.
Implementations
Sourceimpl Variant
impl Variant
pub fn with_scalar<T: DataType>(self, value: &T) -> Self
Sourcepub fn type_id(&self) -> Option<&NodeId>
pub fn type_id(&self) -> Option<&NodeId>
Gets data type’s node ID.
Returns None when the variant is empty.
Sourcepub fn value_type(&self) -> Option<ValueType>
pub fn value_type(&self) -> Option<ValueType>
Gets value type.
Returns None when the variant is empty.
pub fn is_empty(&self) -> bool
pub fn is_scalar(&self) -> bool
pub fn as_scalar<T>(&self) -> Option<&T>where
T: DataType,
pub fn to_scalar<T>(&self) -> Option<T>where
T: DataType,
pub fn into_scalar<T>(self) -> Option<T>where
T: DataType,
pub fn to_array<T: DataType>(&self) -> Option<Array<T>>
pub fn to_value(&self) -> VariantValue
pub fn json(&self) -> Option<Value>